<ol id='status-nav' class='breadcrumb'>
  <li><a id='icon-chart' href='/status'>Status charts</a></li>
  <li><a id='icon-alert' href='/status/alerts'>Status alerts</a></li>
  <li><a class='fa fa-hand-paper-o' href='/status/blacklist/'>Blacklist</a></li>
  <li><a class='fa fa-eye' href='/status/platform-specific-issues/'>Platform-specific issues</a></li>
</ol>
