<div class='container'>
  <noscript>
    Sorry, this page is obsolete. Please check the <a href='../'>homepage</a> instead.
  </noscript>

  <script type='text/javascript'>
    window.location.href = '../';
  </script>
</div>
