#status h3 {
  border-bottom: 1px solid #888a85;
}

.arch-charts {
  height: 250px;
}

.chart {
  height: 180px;
}

.chart h4 {
  text-align: center;
}

.chart-canvas {
   width: 100%;
   height: 200px;
}

#status-nav {
  margin-top: -1.5em;
}

/* -----------------------------------------------------------------
 * headings
 * ----------------------------------------------------------------- */

.page-header {
  margin-top: 0px;
}

.panel .panel-heading {
  background: white;
  font-size: 18px;
}
.panel .panel-heading-browse {
  padding-top: 0px;
  padding-bottom: 0px;
}

/* -----------------------------------------------------------------
 * status marks
 * ----------------------------------------------------------------- */

.pass, .fail, .tmpfail, .no_test_data, .fail_passed_never,
.fail_passed_current, .fail_passed_old, .tmpfail_pass, .tmpfail_fail {
  font-family: 'FontAwesome';
}

.pass:before {
  content: "\f164 ";
  color: #8ae234;
}

.fail:before {
  content: "\f165 ";
  color: #ef2929;
}

.tmpfail:before {
  content: "\f059 ";
  color: #ffd862;
}

.no_test_data:before {
  content: "\f06a ";
  color: #babdb6;
}

.fail_passed_never:before {
  content: "\f165 \f05e ";
  color: #ef2929;
}

.fail_passed_current:before {
  content: "\f165 \f0e7 ";
  color: #9e0000;
}

.fail_passed_old:before {
  content: "\f165 \f063 ";
  color: #c80c0c;
}

.tmpfail_pass:before {
  content: "\f059 \f164 ";
  color: #fffa62;
}

.tmpfail_fail:before {
  content: "\f059 \f165 ";
  color: #ffb062;
}

/* -----------------------------------------------------------------
 * icons
 * ----------------------------------------------------------------- */

#icon-alert:before {
  font-family: "FontAwesome";
  content: "\f071 ";
  color: orange;
  padding-right: 0.3em;
}

#icon-alert:hover {
  text-decoration: none !important;
}

#icon-chart:before {
  font-family: "FontAwesome";
  content: "\f1fe ";
  padding-right: 0.3em;
}

#icon-chart:hover {
  text-decoration: none !important;
}

#icon-rss:before {
  font-family: "FontAwesome";
  content: "\f09e ";
  color: orange;
}

#icon-rss:hover {
  text-decoration: none !important;
}

#icon-tracker:before {
  font-family: "FontAwesome";
  content: "\f05a ";
}

#icon-tracker:hover {
  text-decoration: none !important;
}

/* -----------------------------------------------------------------
 * navbar
 * ----------------------------------------------------------------- */

.navbar-brand {
  background: transparent url(debian.png) 10px 50% no-repeat;
  padding-left: 50px !important;
}

/* -----------------------------------------------------------------
 * footer
 * ----------------------------------------------------------------- */
#wrap {
  min-height: 100%;
  height: auto !important;
  height: 100%;
  margin: 0 auto -60px;
  padding: 0 0 60px;
}
#footer {
  margin-top: 3em;
  padding: 1em;
  min-height: 60px;
  border-top: 1px solid #efefef;
 }
/* -----------------------------------------------------------------
 * package browsing by prefix
 * ----------------------------------------------------------------- */

.list-inline h5 a {
  color: #E90051;
  background-color: #eeeeec;
  padding: 1px 10px;
  border-radius: 5px;
}

.list-inline h5 a:hover {
  text-decoration: none;
  background-color: #E90051;
  color: white;
}
